@@ -3,7 +3,7 @@ import os
 
 class Thing(object):
 
-	def __init__(self, name=None, description=None, grabbable=False, edible=False, taste=None, home=None, alive=False, dead_description=None, hidden=False, containing=[], detail=None, secret_detail=None, ref_name=None):
+	def __init__(self, name=None, description=None, grabbable=True, edible=False, taste=None, home=None, alive=False, dead_description=None, hidden=False, containing=[], detail=None, secret_detail=None, ref_name=None):
 		self.name = name
 		self.description = description
 		self.detail = "You notice nothing of interest."
@@ -43,10 +43,11 @@ def make_things_from_json(gamename):
 		for name, thing_data in things.iteritems():
 			objectlist[name] = Thing()
 			objectlist[name].__dict__.update(thing_data)
-	except IOError:
+	except:
 		pass
-
-make_things_from_json("example")
+		
+objectlist = {}
+#make_things_from_json("example")
 
 
 
